from setuptools import setup
import re

#requirements = []
#with open('requirements.txt') as f:
  #requirements = f.read().splitlines()

version = ''
with open('oneguild/__init__.py') as f:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)

if not version:
    raise RuntimeError('version is not set')

if version.endswith(('a', 'b', 'rc')):
    # append version identifier based on commit count
    try:
        import subprocess
        p = subprocess.Popen(['git', 'rev-list', '--count', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += out.decode('utf-8').strip()
        p = subprocess.Popen(['git', 'rev-parse', '--short', 'HEAD'],
                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        out, err = p.communicate()
        if out:
            version += '+g' + out.decode('utf-8').strip()
    except Exception:
        pass

readme = ''
with open('README.rst') as f:
    readme = f.read()

extras_require = {
    'docs': [
        'sphinx',
        'sphinxcontrib_trio',
        'sphinx-book-theme',
    ],
}

packages = [
    "OneGuild"
]

setup(name='OneGuild',
      author='VincentRPS',
      url='https://github.com/VincentRPS/OneGuild',
      project_urls={
        "Documentation": "https://nextcord.readthedocs.io/en/latest/",
        "Issue tracker": "https://github.com/nextcord/nextcord/issues",
      },
      version=version,
      packages=packages,
      license='Apache-2.0',
      description='An Asynchronous, Pythonic API Wrapper For The Guilded API',
      long_description=readme,
      long_description_content_type="text/x-rst",
      include_package_data=True,
      extras_require=extras_require,
      python_requires='>=3.8.0',
      classifiers=[
        'Development Status :: 5 - Production/Stable',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Typing :: Typed',
      ]
)
